@@ -1,5 +1,6 @@
 from Classification.Classifier.Classifier import Classifier
 from Classification.InstanceList.InstanceList import InstanceList
+from Classification.InstanceList.Partition import Partition
 from Classification.Model.DeepNetworkModel import DeepNetworkModel
 from Classification.Parameter.DeepNetworkParameter import DeepNetworkParameter
 
@@ -17,5 +18,5 @@ class DeepNetwork(Classifier):
         parameters : DeepNetworkParameter
             Parameters of the deep network algorithm. crossValidationRatio and seed are used as parameters.
         """
-        partition = trainSet.stratifiedPartition(parameters.getCrossValidationRatio(), parameters.getSeed())
+        partition = Partition(trainSet, parameters.getCrossValidationRatio(), parameters.getSeed(), True)
         self.model = DeepNetworkModel(partition.get(1), partition.get(0), parameters)
